
package oop6_dat6_u;

/**
 *
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */

public class Sphere implements Comparable<IMyObject>, IMyObject
{

    private int number; //Nummer der Kugel
    private int s1; //Radius

    public Sphere(int no, int a)
    {
        this.number = no;
        this.s1 = a;
    }

    /**
     * Berechnet das Volumen der Kugel
     * @return Volumen
     */
    public int getVolume()
    {
        return (4/3 * (int) Math.PI * s1 * s1 * s1);
    }

    /**
     * Berechnet die Oberfläche des Kubus
     * @return Oberfläche
     */
    public int getSurface()
    {
        return (4 * (int) Math.PI * s1 * s1);
    }

    /**
     * Liefert die grösste Seitenlänge als Ergebnis
     * @return grösse Seitenlänge
     */
    public int getMaxDimension()
    {
        return s1;
    }

    /**
     * String der Kugel
     * @return Beschreibung der Kugel
     */
    @Override
    public String toString()
    {
        /*
        return ("---------------------------------------\n"+
            "SPHERE " + number + "\n" +
            "Radius: " + s1 + "\n" +
            "Volume = " + this.getVolume() + "\n" +
            "Surface = " + this.getSurface()+ "\n");
         */
        return ("SPHERE " + number + " | " +
            "Radius: " + s1 + " | " +
            "Volume = " + this.getVolume() + " | " +
            "Surface = " + this.getSurface()+ "\n");
    }

    /**
     * Kubus vergleichen
     * @param other Kugel
     * @return Kubus gleich oder nicht
     */
    @Override
    public boolean equals(Object other)
    {
        if (this == other) // 1. Test auf Identität
        {
            return true;
        }
        if (other == null) // 2. Test auf null
        {
            return false;
        }
        if (other.getClass() != this.getClass())// 3. Test auf Vergleichbarkeit
        {
            return false;
        }
        if ( ! (this.getVolume() == ((Sphere) other).getVolume()))// 4. Vergleich relev. Felder
        {
            return false;
        }
        return true;
    }

    /**
     * Hash-Code wird bassierend auf der (eindeutigen) Nummer definiert
     * @return Hash-Code
     */
    @Override
    public int hashCode()
    {
        return number;
    }

    /**
     * Kubus wird auf ihre Volumen verglichen
     * @param c Cube zum Vergleichen
     * @return Differenz des Volumen
     */
    public int compareTo(IMyObject c)
    {
        return (this.getVolume() - c.getVolume());
    }


    /**
     * kleine "test" Methode
     * @param args
     */public static void main(String[] args)
    {
        Sphere s1 = new Sphere(1, 1);
        Sphere s2 = new Sphere(2, 10);
        Sphere s3 = new Sphere(3, 30);

        System.out.println(s1.toString());
        System.out.println(s2.toString());
        System.out.println(s3.toString());

        System.out.println("s1 == s2 ? : " + s1.equals(s2));
        System.out.println("s2 == s3 ? : " + s2.equals(s3));
        System.out.println("s1 >  s2 ? : " + s1.compareTo(s2));
        System.out.println("s2 >  s3 ? : " + s2.compareTo(s3));
    }
}
